==> qtjambi-qt3dquick-debuginfo-windows-x64-5.15.18.jar: sources/QtJambi3DQuick/QQmlAspectEngine_shell.h <==
#ifndef QQMLASPECTENGINE_SHELL_H
#define QQMLASPECTENGINE_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <Qt3DQuick/qqmlaspectengine.h>
#include <QtJambi/QtJambiAPI>
#include <Qt3DCore/qaspectengine.h>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qregexp.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtCore/qurl.h>
#include <QtJambi/QmlAPI>
#include <QtQml/qqmlengine.h>
#include <QtJambi/RegistryAPI>


class QQmlAspectEngine_shell : public Qt3DCore::Quick::QQmlAspectEngine, public QtJambiShellInterface
{
public:
    QQmlAspectEngine_shell(QObject* parent0 = nullptr);
    ~QQmlAspectEngine_shell() override;

    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QQmlAspectEngine_access : public Qt3DCore::Quick::QQmlAspectEngine
{
};

#endif // QQMLASPECTENGINE_SHELL_H

==> qtjambi-qt3dquick-debuginfo-windows-x64-6.6.0.jar: sources/QtJambi3DQuick/QQmlAspectEngine_shell.h <==
#ifndef QQMLASPECTENGINE_SHELL_H
#define QQMLASPECTENGINE_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED

#include <Qt3DQuick/qqmlaspectengine.h>
#include <QtJambi/QtJambiAPI>
#include <Qt3DCore/qaspectengine.h>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qproperty.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtCore/qurl.h>
#include <QtCore/qvariant.h>
#include <QtJambi/QmlAPI>
#include <QtQml/qqmlengine.h>
#include <QtJambi/RegistryAPI>


class QQmlAspectEngine_shell : public Qt3DCore::Quick::QQmlAspectEngine, public QtJambiShellInterface
{
public:
    QQmlAspectEngine_shell(QObject* parent0 = nullptr);
    ~QQmlAspectEngine_shell() override;

    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QQmlAspectEngine_access : public Qt3DCore::Quick::QQmlAspectEngine
{
};

#endif // QQMLASPECTENGINE_SHELL_H
